<?php

namespace Drupal\Tests\moderation_scheduler\Functional;

/**
 * Tests the modules primary function - publishing content.
 *
 * @group moderation_scheduler
 */
class ModerationSchedulerBasicTest extends ModerationSchedulerBrowserTestBase {

  /**
   * Tests basic scheduling of content.
   */
  public function testPublishingAndUnpublishing() {
    // Login is required here before creating the publish_on date and time
    // values so that date.formatter can utilise the current users timezone. The
    // constraints receive values which have been converted using the users
    // timezone so they need to be consistent.
    $this->drupalLogin($this->moderation_schedulerUser);
    $timestamp = REQUEST_TIME - 87654321;

    // Create node values. Set time to one hour in the future.
    $date_formatter = \Drupal::service('date.formatter');

    $edit = [
      'title[0][value]' => 'Publish This Node',
      'field_scheduled_time[0][value][date]' => $date_formatter->format($timestamp, 'custom', 'Y-m-d'),
      'field_scheduled_time[0][value][time]' => $date_formatter->format($timestamp, 'custom', 'H:i:s'),
    ];
    $this->helpTestModerationScheduler($edit);
  }

  /**
   * Helper function for testPublishingAndUnpublishing().
   *
   * Schedules content, runs cron and asserts status.
   */
  protected function helpTestModerationScheduler($edit) {

    $this->drupalPostForm('node/add/page', $edit, t('Save'));

    // Modify the moderation_scheduler field data to a time in the past, then run cron.
    // Verify that the node was created.
    if (empty($node)) {
      $this->assert(FALSE, 'Test halted because node was not created.');
      return;
    }
    $this->cronRun();

    $node = $this->drupalGetNodeByTitle($edit['title[0][value]']);

    // Refresh the node cache and check the node status.
    $this->nodeStorage->resetCache([$node->id()]);
    $node = $this->nodeStorage->load($node->id());

    $this->assertTrue($node->isPublished());

  }

}
